// Code generated by gocc; DO NOT EDIT.

package parser

const numNTSymbols = 3

type (
	gotoTable [numStates]gotoRow
	gotoRow   [numNTSymbols]int
)

var gotoTab = gotoTable{
	gotoRow{ // S0
		-1, // S'
		1,  // Grammar
		2,  // Words
	},
	gotoRow{ // S1
		-1, // S'
		-1, // Grammar
		-1, // Words
	},
	gotoRow{ // S2
		-1, // S'
		-1, // Grammar
		-1, // Words
	},
	gotoRow{ // S3
		-1, // S'
		-1, // Grammar
		-1, // Words
	},
	gotoRow{ // S4
		-1, // S'
		-1, // Grammar
		-1, // Words
	},
	gotoRow{ // S5
		-1, // S'
		-1, // Grammar
		-1, // Words
	},
	gotoRow{ // S6
		-1, // S'
		-1, // Grammar
		-1, // Words
	},
	gotoRow{ // S7
		-1, // S'
		-1, // Grammar
		-1, // Words
	},
}
