//Copyright 2013 Vastech SA (PTY) LTD
//
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.

package io

import (
	"os"
	"path"
)

const PermDir = 0777
const PermFile = 0666

func WriteFile(fpath string, data []byte) {
	dir, _ := path.Split(fpath)
	if err := os.MkdirAll(dir, PermDir); err != nil {
		panic(err)
	}
	if err := os.WriteFile(fpath, data, PermFile); err != nil {
		panic(err)
	}
}

func WriteFileString(fpath string, data string) {
	WriteFile(fpath, []byte(data))
}
