// Code generated by gocc; DO NOT EDIT.

package lexer

/*
Let s be the current state
Let r be the current input rune
transitionTable[s](r) returns the next state.
*/
type TransitionTable [NumStates]func(rune) int

var TransTab = TransitionTable{
	// S0
	func(r rune) int {
		switch {
		case r == 10: // ['\n','\n']
			return 1
		case r == 13: // ['\r','\r']
			return 2
		case r == 32: // [' ',' ']
			return 1
		case r == 46: // ['.','.']
			return 3
		case 65 <= r && r <= 90: // ['A','Z']
			return 4
		case 97 <= r && r <= 122: // ['a','z']
			return 5
		}
		return NoState
	},
	// S1
	func(r rune) int {
		switch {
		}
		return NoState
	},
	// S2
	func(r rune) int {
		switch {
		case r == 10: // ['\n','\n']
			return 1
		}
		return NoState
	},
	// S3
	func(r rune) int {
		switch {
		case r == 46: // ['.','.']
			return 6
		}
		return NoState
	},
	// S4
	func(r rune) int {
		switch {
		case 65 <= r && r <= 90: // ['A','Z']
			return 4
		case 97 <= r && r <= 122: // ['a','z']
			return 4
		}
		return NoState
	},
	// S5
	func(r rune) int {
		switch {
		case 97 <= r && r <= 122: // ['a','z']
			return 5
		}
		return NoState
	},
	// S6
	func(r rune) int {
		switch {
		case r == 46: // ['.','.']
			return 7
		}
		return NoState
	},
	// S7
	func(r rune) int {
		switch {
		case r == 52: // ['4','4']
			return 8
		}
		return NoState
	},
	// S8
	func(r rune) int {
		switch {
		case r == 50: // ['2','2']
			return 9
		}
		return NoState
	},
	// S9
	func(r rune) int {
		switch {
		case r == 46: // ['.','.']
			return 10
		}
		return NoState
	},
	// S10
	func(r rune) int {
		switch {
		case r == 46: // ['.','.']
			return 11
		}
		return NoState
	},
	// S11
	func(r rune) int {
		switch {
		case r == 46: // ['.','.']
			return 12
		}
		return NoState
	},
	// S12
	func(r rune) int {
		switch {
		}
		return NoState
	},
}
