//Copyright 2013 Vastech SA (PTY) LTD
//
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.

package golang

import (
	"github.com/goccmack/gocc/internal/lexer/symbols"
)

type CharRange struct {
	Min, Max rune
	Type     int
	Comment  string
}

func getCharRanges(symbols *symbols.Symbols) (ranges []CharRange) {
	ranges = make([]CharRange, symbols.CharRangeSymbols.Len())
	for i, rng := range symbols.CharRangeSymbols.List() {
		cr := CharRange{
			Min:     rng.From.Val,
			Max:     rng.To.Val,
			Type:    symbols.Type(rng.String()),
			Comment: rng.String(),
		}
		ranges[i] = cr
	}
	return
}
