package token

var FRONTENDTokens = NewMapFromStrings([]string{
	"id",
	"tokId",
	":",
	";",
	"regDefId",
	"ignoredTokId",
	"|",
	".",
	"char_lit",
	"-",
	"[",
	"]",
	"{",
	"}",
	"(",
	")",
	"prodId",
	"g_sdt_lit",
	"error",
	"empty",
	"string_lit",
})
