// Code generated by gocc; DO NOT EDIT.

package parser

type (
	actionTable [numStates]actionRow
	actionRow   struct {
		canRecover bool
		actions    [numSymbols]action
	}
)

var actionTab = actionTable{
	actionRow{ // S0
		canRecover: false,
		actions: [numSymbols]action{
			nil,      // INVALID
			nil,      // ␚
			nil,      // ...42...
			shift(3), // capitalized
			shift(4), // lowercase
		},
	},
	actionRow{ // S1
		canRecover: false,
		actions: [numSymbols]action{
			nil,          // INVALID
			accept(true), // ␚
			nil,          // ...42...
			nil,          // capitalized
			nil,          // lowercase
		},
	},
	actionRow{ // S2
		canRecover: false,
		actions: [numSymbols]action{
			nil,      // INVALID
			nil,      // ␚
			shift(5), // ...42...
			shift(6), // capitalized
			shift(7), // lowercase
		},
	},
	actionRow{ // S3
		canRecover: false,
		actions: [numSymbols]action{
			nil,       // INVALID
			nil,       // ␚
			reduce(2), // ...42..., reduce: Words
			reduce(2), // capitalized, reduce: Words
			reduce(2), // lowercase, reduce: Words
		},
	},
	actionRow{ // S4
		canRecover: false,
		actions: [numSymbols]action{
			nil,       // INVALID
			nil,       // ␚
			reduce(4), // ...42..., reduce: Words
			reduce(4), // capitalized, reduce: Words
			reduce(4), // lowercase, reduce: Words
		},
	},
	actionRow{ // S5
		canRecover: false,
		actions: [numSymbols]action{
			nil,       // INVALID
			reduce(1), // ␚, reduce: Grammar
			nil,       // ...42...
			nil,       // capitalized
			nil,       // lowercase
		},
	},
	actionRow{ // S6
		canRecover: false,
		actions: [numSymbols]action{
			nil,       // INVALID
			nil,       // ␚
			reduce(3), // ...42..., reduce: Words
			reduce(3), // capitalized, reduce: Words
			reduce(3), // lowercase, reduce: Words
		},
	},
	actionRow{ // S7
		canRecover: false,
		actions: [numSymbols]action{
			nil,       // INVALID
			nil,       // ␚
			reduce(5), // ...42..., reduce: Words
			reduce(5), // capitalized, reduce: Words
			reduce(5), // lowercase, reduce: Words
		},
	},
}
